@@ -1,8 +1,8 @@
 import coloredlogs, logging
-import warnings, os
+import warnings
 warnings.filterwarnings('ignore')
 
 logger = logging.getLogger(__name__)
 coloredlogs.install(level='DEBUG', logger=logger)
 
-default_field: str = "N/A"
\ No newline at end of file
+default_field: str = "N/A"
